@@ -1,21 +1,20 @@
 import os
 import requests
-from stochasticx.constants.urls import ME_URL
+from stochasticx.constants.urls import CloudRoutes, get_cloud_url
 from stochasticx.utils.auth_utils import AuthUtils, LoginUtils
 import ipywidgets as widgets
 from IPython.display import display
 
 
 class UsageQuota:
-    """Class to get your current usage quota and your limits
-    """
-    
+    """Class to get your current usage quota and your limits"""
+
     def __init__(
         self,
         concurrentJobLimit: int,
         monthlyJobLimit: int,
         storageUsed: int,
-        storageLimit: int
+        storageLimit: int,
     ):
         """Initializer
 
@@ -25,12 +24,12 @@ class UsageQuota:
             storageUsed (int): storage used
             storageLimit (int): storage limit
         """
-        
+
         self.concurrentJobLimit = concurrentJobLimit
         self.monthlyJobLimit = monthlyJobLimit
         self.storageUsed = storageUsed
         self.storageLimit = storageLimit
-        
+
     def __str__(self):
         """Convert the object to a string
 
@@ -46,20 +45,14 @@ class UsageQuota:
             self.concurrentJobLimit,
             self.monthlyJobLimit,
             self.storageUsed,
-            self.storageLimit
+            self.storageLimit,
         )
-        
+
 
 class Company:
-    """Class to store information about the company of the user
-    """
-    
-    def __init__(
-        self,
-        id: str,
-        name: str,
-        website: str
-    ):
+    """Class to store information about the company of the user"""
+
+    def __init__(self, id: str, name: str, website: str):
         """Initializer
 
         Args:
@@ -67,11 +60,11 @@ class Company:
             name (str): company name
             website (str): website
         """
-        
+
         self.id = id
         self.name = name
         self.website = website
-        
+
     def __str__(self):
         """Method to convert the object to a string
 
@@ -83,24 +76,14 @@ class Company:
     Company name: {} 
     Website: {}
 """.format(
-            self.id,
-            self.name,
-            self.website
+            self.id, self.name, self.website
         )
-        
+
 
 class User:
-    """Class to store information about the user
-    """
-    
-    def __init__(
-        self, 
-        id: str, 
-        first_name: str, 
-        last_name: str, 
-        email: str, 
-        role: str
-    ):
+    """Class to store information about the user"""
+
+    def __init__(self, id: str, first_name: str, last_name: str, email: str, role: str):
         """Initializer
 
         Args:
@@ -110,13 +93,13 @@ class User:
             email (str): email
             role (str): role
         """
-        
+
         self.id = id
         self.first_name = first_name
         self.last_name = last_name
         self.email = email
         self.role = role
-        
+
     def __str__(self):
         """Method to conver the object to a string
 
@@ -130,25 +113,16 @@ class User:
     Email: {} 
     Role: {}
 """.format(
-            self.id,
-            self.first_name,
-            self.last_name,
-            self.email,
-            self.role
+            self.id, self.first_name, self.last_name, self.email, self.role
         )
 
 
-
 class Stochastic:
-    """Class to do login and store the information of the current user
-    """
-    
-    def __init__(
-        self
-    ):
-        """Initializer
-        """
-        
+    """Class to do login and store the information of the current user"""
+
+    def __init__(self):
+        """Initializer"""
+
         self.username = os.getenv("STOCHASTIC_USER")
         self.password = os.getenv("STOCHASTIC_PASSWORD")
         self.company_info = None
@@ -156,23 +130,25 @@ class Stochastic:
         self.user_info = None
 
     def login(self):
-        """Do login
-        """
-        
+        """Do login"""
+
         LoginUtils.login_request(self.username, self.password)
-        
+
     def login(self, username, password):
+        os.environ["STOCHASTIC_USER"] = username
         LoginUtils.login_request(username, password)
-    
+
+    def link_login(self):
+        LoginUtils.link_login_request()
+
     def notebook_login(self):
-        """Allows you to login in a Jupyter Notebook
-        """
-        
+        """Allows you to login in a Jupyter Notebook"""
+
         username = widgets.Text(description="Username")
         password = widgets.Password(description="Password")
         output = widgets.Output()
         login_button = widgets.Button(description="Login")
-        
+
         display(username, password, login_button, output)
 
         def on_button_clicked(b):
@@ -184,38 +160,37 @@ class Stochastic:
                     print("Username or password is not correct")
 
         login_button.on_click(on_button_clicked)
-        
+
     def _initilize_profile(self):
-        """Populate the profile with data
-        """
-        
+        """Populate the profile with data"""
+
         auth_header = AuthUtils.get_auth_headers()
-        
-        response = requests.get(ME_URL, headers=auth_header)
+
+        response = requests.get(get_cloud_url(CloudRoutes.ME_URL), headers=auth_header)
         data = response.json()
-                
+
         if data.get("company") is not None:
             self.company_info = Company(
                 id=data.get("company").get("id"),
                 name=data.get("company").get("name"),
-                website=data.get("company").get("website")
+                website=data.get("company").get("website"),
             )
-            
+
             self.usage_quota = UsageQuota(
                 concurrentJobLimit=data.get("company").get("concurrentJobLimit"),
                 monthlyJobLimit=data.get("company").get("monthlyJobLimit"),
                 storageUsed=data.get("company").get("storageUsed"),
-                storageLimit=data.get("company").get("storageLimit")
+                storageLimit=data.get("company").get("storageLimit"),
             )
-        
+
         self.user_info = User(
             id=data.get("id"),
             first_name=data.get("firstName"),
             last_name=data.get("lastName"),
             email=data.get("email"),
-            role=data.get("role")
+            role=data.get("role"),
         )
-        
+
     def get_profile(self):
         """Returns profile information
 
@@ -224,7 +199,7 @@ class Stochastic:
         """
         self._initilize_profile()
         return self.user_info
-    
+
     def get_company(self):
         """Returns the company information
 
@@ -233,7 +208,7 @@ class Stochastic:
         """
         self._initilize_profile()
         return self.company_info
-    
+
     def get_usage_quota(self):
         """Return the usage quota
 
@@ -241,4 +216,4 @@ class Stochastic:
             UsageQuota: usage quota
         """
         self._initilize_profile()
-        return self.usage_quota
\ No newline at end of file
+        return self.usage_quota
