@@ -6,6 +6,12 @@ from typing import Dict, List
 from stochasticx.constants.urls import FINETUNING_GET_JOBS_CLOUD_URL
 from stochasticx.utils.parse_utils import parse_date
 from stochasticx.utils.auth_utils import AuthUtils
+from stochasticx.utils.stat_controller import (
+    StatController,
+    LocalFinetuningJobInformation,
+)
+from stochasticx.utils.preferences import AppModes, Preferences
+
 
 @dataclass
 class CloudEvaluationResults:
@@ -17,9 +23,9 @@ class CloudEvaluationResults:
 \t Model name: {}
 \t Evaluation benchmarks: {}        
 """.format(
-    self.model_name,
-    self.evaluation_benchmark
-)
+            self.model_name, self.evaluation_benchmark
+        )
+
 
 @dataclass
 class CloudFinetuningJob:
@@ -37,30 +43,17 @@ Status: {}
 Created at: {}
 Results:
 """.format(
-    self.id,
-    self.name,
-    self.job_status,
-    self.created_at
-)
+            self.id, self.name, self.job_status, self.created_at
+        )
         for result in self.results:
             string += result.__str__()
 
         return string
 
     def to_table(self):
-        columns = [
-            "ID",
-            "Name",
-            "Status",
-            "Created at"
-        ]
+        columns = ["ID", "Name", "Status", "Created at"]
 
-        values = [
-            self.id,
-            self.name,
-            self.job_status,
-            parse_date(self.created_at)
-        ]
+        values = [self.id, self.name, self.job_status, parse_date(self.created_at)]
 
         return columns, values
 
@@ -85,21 +78,22 @@ class CloudSequenceClassificationFinetuning(CloudFinetuningJob):
             "selectedColumns": {
                 "sentence1_column": self.sentence1_column,
                 "sentence2_column": self.sentence2_column,
-                "label_column": self.label_column
+                "label_column": self.label_column,
             },
-            "taskArguments": {
-                "max_seq_length": self.max_seq_length
-            },
-            "taskType": self.task_type
+            "taskArguments": {"max_seq_length": self.max_seq_length},
+            "taskType": self.task_type,
         }
 
         auth_header = AuthUtils.get_auth_headers()
-        response = requests.post(FINETUNING_GET_JOBS_CLOUD_URL, json=data, headers=auth_header)
+        response = requests.post(
+            FINETUNING_GET_JOBS_CLOUD_URL, json=data, headers=auth_header
+        )
         response.raise_for_status()
         data = response.json()
 
         return data.get("id")
 
+
 @dataclass
 class CloudQuestionAnsweringFinetuning(CloudFinetuningJob):
     dataset_id: str = None
@@ -121,16 +115,16 @@ class CloudQuestionAnsweringFinetuning(CloudFinetuningJob):
             "selectedColumns": {
                 "question_column": self.question_column,
                 "context_column": self.context_column,
-                "answer_column": self.answer_column
+                "answer_column": self.answer_column,
             },
-            "taskArguments": {
-                "max_seq_length": self.max_seq_length
-            },
-            "taskType": self.task_type
+            "taskArguments": {"max_seq_length": self.max_seq_length},
+            "taskType": self.task_type,
         }
 
         auth_header = AuthUtils.get_auth_headers()
-        response = requests.post(FINETUNING_GET_JOBS_CLOUD_URL, json=data, headers=auth_header)
+        response = requests.post(
+            FINETUNING_GET_JOBS_CLOUD_URL, json=data, headers=auth_header
+        )
         response.raise_for_status()
         data = response.json()
 
@@ -156,17 +150,19 @@ class CloudTokenClassificationFinetuning(CloudFinetuningJob):
             "modelSource": self.model_source,
             "selectedColumns": {
                 "text_column": self.text_column,
-                "label_column": self.label_column
+                "label_column": self.label_column,
             },
             "taskArguments": {
                 "max_seq_length": self.max_seq_length,
-                "label_all_tokens": self.label_all_tokens
+                "label_all_tokens": self.label_all_tokens,
             },
-            "taskType": self.task_type
+            "taskType": self.task_type,
         }
 
         auth_header = AuthUtils.get_auth_headers()
-        response = requests.post(FINETUNING_GET_JOBS_CLOUD_URL, json=data, headers=auth_header)
+        response = requests.post(
+            FINETUNING_GET_JOBS_CLOUD_URL, json=data, headers=auth_header
+        )
         response.raise_for_status()
         data = response.json()
 
@@ -198,7 +194,7 @@ class CloudSummarizationFinetuning(CloudFinetuningJob):
             "modelSource": self.model_source,
             "selectedColumns": {
                 "text_column": self.text_column,
-                "summary_column": self.summary_column
+                "summary_column": self.summary_column,
             },
             "taskArguments": {
                 "max_source_length": self.max_source_length,
@@ -208,13 +204,15 @@ class CloudSummarizationFinetuning(CloudFinetuningJob):
                 "num_beams": self.num_beams,
                 "ignore_pad_token_for_loss": self.ignore_pad_token_for_loss,
                 "source_prefix": self.source_prefix,
-                "forced_bos_token": self.forced_bos_token
+                "forced_bos_token": self.forced_bos_token,
             },
-            "taskType": self.task_type
+            "taskType": self.task_type,
         }
 
         auth_header = AuthUtils.get_auth_headers()
-        response = requests.post(FINETUNING_GET_JOBS_CLOUD_URL, json=data, headers=auth_header)
+        response = requests.post(
+            FINETUNING_GET_JOBS_CLOUD_URL, json=data, headers=auth_header
+        )
         response.raise_for_status()
         data = response.json()
 
@@ -244,9 +242,7 @@ class CloudTranslationFinetuning(CloudFinetuningJob):
             "jobName": self.name,
             "model": self.model_id,
             "modelSource": self.model_source,
-            "selectedColumns": {
-                "translation_column": self.translation_column
-            },
+            "selectedColumns": {"translation_column": self.translation_column},
             "taskArguments": {
                 "max_source_length": self.max_source_length,
                 "max_target_length": self.max_target_length,
@@ -256,13 +252,15 @@ class CloudTranslationFinetuning(CloudFinetuningJob):
                 "num_beams": self.num_beams,
                 "ignore_pad_token_for_loss": self.ignore_pad_token_for_loss,
                 "source_prefix": self.source_prefix,
-                "forced_bos_token": self.forced_bos_token
+                "forced_bos_token": self.forced_bos_token,
             },
-            "taskType": self.task_type
+            "taskType": self.task_type,
         }
 
         auth_header = AuthUtils.get_auth_headers()
-        response = requests.post(FINETUNING_GET_JOBS_CLOUD_URL, json=data, headers=auth_header)
+        response = requests.post(
+            FINETUNING_GET_JOBS_CLOUD_URL, json=data, headers=auth_header
+        )
         response.raise_for_status()
         data = response.json()
 
@@ -283,17 +281,15 @@ class CloudTextGenerationFinetuning(CloudFinetuningJob):
             "jobName": self.name,
             "model": self.model_id,
             "modelSource": self.model_source,
-            "selectedColumns": {
-                "text_column": self.text_column
-            },
-            "taskArguments": {
-
-            },
-            "taskType": self.task_type
+            "selectedColumns": {"text_column": self.text_column},
+            "taskArguments": {},
+            "taskType": self.task_type,
         }
 
         auth_header = AuthUtils.get_auth_headers()
-        response = requests.post(FINETUNING_GET_JOBS_CLOUD_URL, json=data, headers=auth_header)
+        response = requests.post(
+            FINETUNING_GET_JOBS_CLOUD_URL, json=data, headers=auth_header
+        )
         response.raise_for_status()
         data = response.json()
 
@@ -308,7 +304,7 @@ class CloudFinetuningClient:
         response.raise_for_status()
 
         data = response.json()
-        finetuning_jobs=[]
+        finetuning_jobs = []
 
         if data.get("data") is not None:
             for job in data.get("data"):
@@ -319,7 +315,7 @@ class CloudFinetuningClient:
                     for result in results:
                         er = CloudEvaluationResults(
                             model_name=result.get("modelName"),
-                            evaluation_benchmark=result.get("evaluationBenchmark")
+                            evaluation_benchmark=result.get("evaluationBenchmark"),
                         )
 
                         evaluation_results.append(er)
@@ -329,7 +325,7 @@ class CloudFinetuningClient:
                     name=job.get("name"),
                     job_status=job.get("jobStatus").get("value"),
                     created_at=job.get("createdAt"),
-                    results=evaluation_results
+                    results=evaluation_results,
                 )
 
                 finetuning_jobs.append(finetuning_job)
@@ -337,14 +333,14 @@ class CloudFinetuningClient:
             if fmt == "table":
                 columns = []
                 values = []
-                
+
                 if len(finetuning_jobs) > 0:
                     columns, _ = finetuning_jobs[0].to_table()
-                    
+
                 for job in finetuning_jobs:
                     _, vals = job.to_table()
                     values.append(vals)
-                    
+
                 return columns, values
 
         return finetuning_jobs
@@ -353,8 +349,7 @@ class CloudFinetuningClient:
     def get_cloud_finetuning_by_id(cls, id):
         auth_header = AuthUtils.get_auth_headers()
         response = requests.get(
-            "{}/{}".format(FINETUNING_GET_JOBS_CLOUD_URL, id),
-            headers=auth_header
+            "{}/{}".format(FINETUNING_GET_JOBS_CLOUD_URL, id), headers=auth_header
         )
         response.raise_for_status()
 
@@ -369,7 +364,7 @@ class CloudFinetuningClient:
                 for result in results:
                     er = CloudEvaluationResults(
                         model_name=result.get("modelName"),
-                        evaluation_benchmark=result.get("evaluationBenchmark")
+                        evaluation_benchmark=result.get("evaluationBenchmark"),
                     )
 
                     evaluation_results.append(er)
@@ -379,17 +374,19 @@ class CloudFinetuningClient:
                 name=job.get("name"),
                 job_status=job.get("jobStatus").get("value"),
                 created_at=job.get("createdAt"),
-                results=evaluation_results
+                results=evaluation_results,
             )
 
             return finetuning_job
 
         return None
 
+
 class LocalFinetuningClient:
     @classmethod
     def get_local_finetuning_jobs(cls, fmt="table"):
-        response = requests.get("http://127.0.0.1:5050/jobs")
+        preferences = Preferences.load()
+        response = requests.get(f"{preferences.local_finetuning_url}/jobs")
         response.raise_for_status()
 
         data = response.json()
@@ -400,11 +397,9 @@ class LocalFinetuningClient:
 
                 values = []
                 for entry in data:
-                    values.append([
-                        entry.get('name'),
-                        entry.get('status'),
-                        entry.get('createdAt')
-                    ])
+                    values.append(
+                        [entry.get("name"), entry.get("status"), entry.get("createdAt")]
+                    )
 
                 return columns, values
 
@@ -413,17 +408,21 @@ class LocalFinetuningClient:
 
     @classmethod
     def get_logs(cls, job_name, fmt="table"):
-        response = requests.get("http://127.0.0.1:5050/jobs/{}/logs".format(job_name))
+        preferences = Preferences.load()
+        response = requests.get(
+            "{}/jobs/{}/logs".format(preferences.local_finetuning_url, job_name)
+        )
 
         try:
             response.raise_for_status()
         except:
-            click.secho("\n[+] This job does not exist\n", fg='red', bold=True)
+            click.secho("\n[+] This job does not exist\n", fg="red", bold=True)
 
         data = response.json()
 
         return data.get("logs")
 
+
 @dataclass
 class LocalFinetuning:
     job_name: str
@@ -444,10 +443,30 @@ class LocalSequenceClassification(LocalFinetuning):
     label_column: str = "label"
 
     def start_finetuning(self):
-        data = asdict(self)
 
-        response = requests.post("http://127.0.0.1:5050/jobs", json=data)
+        data = asdict(self)
+        preferences = Preferences.load()
+        response = requests.post(f"{preferences.local_finetuning_url}/jobs", json=data)
         response.raise_for_status()
+        StatController.add_information(
+            LocalFinetuningJobInformation(
+                job_name=self.job_name,
+                inference_type=self.task_type,
+                model_name=self.model_name,
+                dataset_name=self.dataset_name,
+                job_result=response.json(),
+                params={
+                    "num_train_epochs": self.num_train_epochs,
+                    "per_device_train_batch_size": self.per_device_train_batch_size,
+                    "per_device_eval_batch_size": self.per_device_eval_batch_size,
+                    "learning_rate": self.learning_rate,
+                    "max_seq_length": self.max_seq_length,
+                    "sentence1_column": self.sentence1_column,
+                    "sentence2_column": self.sentence2_column,
+                    "label_column": self.label_column,
+                },
+            )
+        )
 
 
 @dataclass
@@ -461,13 +480,35 @@ class LocalQuestionAnswering(LocalFinetuning):
 
     def start_finetuning(self):
         data = asdict(self)
-
-        response = requests.post("http://127.0.0.1:5050/jobs", json=data)
+        preferences = Preferences.load()
+        response = requests.post(f"{preferences.local_finetuning_url}/jobs", json=data)
         response.raise_for_status()
 
+        StatController.add_information(
+            LocalFinetuningJobInformation(
+                job_name=self.job_name,
+                inference_type=self.task_type,
+                model_name=self.model_name,
+                dataset_name=self.dataset_name,
+                job_result=response.json(),
+                params={
+                    "num_train_epochs": self.num_train_epochs,
+                    "per_device_train_batch_size": self.per_device_train_batch_size,
+                    "per_device_eval_batch_size": self.per_device_eval_batch_size,
+                    "learning_rate": self.learning_rate,
+                    "max_seq_length": self.max_seq_length,
+                    "stride": self.stride,
+                    "question_column": self.question_column,
+                    "context_column": self.context_column,
+                    "answer_column": self.answer_column,
+                },
+            )
+        )
+
 
 @dataclass
 class LocalTokenClassification(LocalFinetuning):
+    task_type: str = "token_classification"
     max_seq_length: int = 128
     label_all_tokens: bool = False
     text_column: str = "tokens"
@@ -475,13 +516,34 @@ class LocalTokenClassification(LocalFinetuning):
 
     def start_finetuning(self):
         data = asdict(self)
-
-        response = requests.post("http://127.0.0.1:5050/jobs", json=data)
+        preferences = Preferences.load()
+        response = requests.post(f"{preferences.local_finetuning_url}/jobs", json=data)
         response.raise_for_status()
 
+        StatController.add_information(
+            LocalFinetuningJobInformation(
+                job_name=self.job_name,
+                inference_type=self.task_type,
+                model_name=self.model_name,
+                dataset_name=self.dataset_name,
+                job_result=response.json(),
+                params={
+                    "num_train_epochs": self.num_train_epochs,
+                    "per_device_train_batch_size": self.per_device_train_batch_size,
+                    "per_device_eval_batch_size": self.per_device_eval_batch_size,
+                    "learning_rate": self.learning_rate,
+                    "max_seq_length": self.max_seq_length,
+                    "label_all_tokens": self.label_all_tokens,
+                    "text_column": self.text_column,
+                    "label_column": self.label_column,
+                },
+            )
+        )
+
 
 @dataclass
 class LocalSummarization(LocalFinetuning):
+    task_type: str = "summarization"
     max_source_length: int = 256
     max_target_length: int = 32
     lang: str = "en"
@@ -495,13 +557,40 @@ class LocalSummarization(LocalFinetuning):
 
     def start_finetuning(self):
         data = asdict(self)
-
-        response = requests.post("http://127.0.0.1:5050/jobs", json=data)
+        preferences = Preferences.load()
+        response = requests.post(f"{preferences.local_finetuning_url}/jobs", json=data)
         response.raise_for_status()
 
+        StatController.add_information(
+            LocalFinetuningJobInformation(
+                job_name=self.job_name,
+                inference_type=self.task_type,
+                model_name=self.model_name,
+                dataset_name=self.dataset_name,
+                job_result=response.json(),
+                params={
+                    "num_train_epochs": self.num_train_epochs,
+                    "per_device_train_batch_size": self.per_device_train_batch_size,
+                    "per_device_eval_batch_size": self.per_device_eval_batch_size,
+                    "learning_rate": self.learning_rate,
+                    "max_source_length": self.max_source_length,
+                    "max_target_length": self.max_target_length,
+                    "lang": self.lang,
+                    "pad_to_max_length": self.pad_to_max_length,
+                    "num_beams": self.num_beams,
+                    "ignore_pad_token_for_loss": self.ignore_pad_token_for_loss,
+                    "source_prefix": self.source_prefix,
+                    "forced_bos_token": self.forced_bos_token,
+                    "text_column": self.text_column,
+                    "summary_column": self.summary_column,
+                },
+            )
+        )
+
 
 @dataclass
 class LocalTranslation(LocalFinetuning):
+    task_type: str = "translation"
     max_source_length: int = 128
     max_target_length: int = 128
     src_lang: str = "en"
@@ -515,10 +604,36 @@ class LocalTranslation(LocalFinetuning):
 
     def start_finetuning(self):
         data = asdict(self)
-
-        response = requests.post("http://127.0.0.1:5050/jobs", json=data)
+        preferences = Preferences.load()
+        response = requests.post(f"{preferences.local_finetuning_url}/jobs", json=data)
         response.raise_for_status()
 
+        StatController.add_information(
+            LocalFinetuningJobInformation(
+                job_name=self.job_name,
+                inference_type=self.task_type,
+                model_name=self.model_name,
+                dataset_name=self.dataset_name,
+                job_result=response.json(),
+                params={
+                    "num_train_epochs": self.num_train_epochs,
+                    "per_device_train_batch_size": self.per_device_train_batch_size,
+                    "per_device_eval_batch_size": self.per_device_eval_batch_size,
+                    "learning_rate": self.learning_rate,
+                    "max_source_length": self.max_source_length,
+                    "max_target_length": self.max_target_length,
+                    "src_lang": self.src_lang,
+                    "tgt_lang": self.tgt_lang,
+                    "pad_to_max_length": self.pad_to_max_length,
+                    "num_beams": self.num_beams,
+                    "ignore_pad_token_for_loss": self.ignore_pad_token_for_loss,
+                    "source_prefix": self.source_prefix,
+                    "forced_bos_token": self.forced_bos_token,
+                    "translation_column": self.translation_column,
+                },
+            )
+        )
+
 
 @dataclass
 class LocalTextGeneration(LocalFinetuning):
@@ -526,6 +641,6 @@ class LocalTextGeneration(LocalFinetuning):
 
     def start_finetuning(self):
         data = asdict(self)
-
-        response = requests.post("http://127.0.0.1:5050/jobs", json=data)
-        response.raise_for_status()
\ No newline at end of file
+        preferences = Preferences.load()
+        response = requests.post(f"{preferences.local_finetuning_url}/jobs", json=data)
+        response.raise_for_status()
