@@ -2,26 +2,29 @@ import sys
 import time
 import threading
 
+
 class Spinner:
     # Taken from Stack OverFlow: https://stackoverflow.com/questions/4995733/how-to-create-a-spinning-command-line-cursor
     busy = False
-    delay = 0.1
+    delay = 0.2
 
     @staticmethod
     def spinning_cursor():
-        while 1: 
-            for cursor in '|/-\\': yield cursor
+        while 1:
+            for cursor in "|/-\\":
+                yield cursor
 
     def __init__(self, delay=None):
         self.spinner_generator = self.spinning_cursor()
-        if delay and float(delay): self.delay = delay
+        if delay and float(delay):
+            self.delay = delay
 
     def spinner_task(self):
         while self.busy:
             sys.stdout.write(next(self.spinner_generator))
             sys.stdout.flush()
             time.sleep(self.delay)
-            sys.stdout.write('\b')
+            sys.stdout.write("\b")
             sys.stdout.flush()
 
     def __enter__(self):
@@ -32,4 +35,4 @@ class Spinner:
         self.busy = False
         time.sleep(self.delay)
         if exception is not None:
-            return False
\ No newline at end of file
+            return False
